diff --git a/src/Main/main.cxx b/src/Main/main.cxx
index 2b6ffa0ac..9de75380c 100644
--- a/src/Main/main.cxx
+++ b/src/Main/main.cxx
@@ -405,10 +405,11 @@ static void upper_case_property(const char *name)
     p->addChangeListener(muc);
 }
 
 // Propose NVIDIA Optimus to use high-end GPU
 #if defined(SG_WINDOWS)
 extern "C" {
     _declspec(dllexport) DWORD NvOptimusEnablement = 0x00000001;
+    _declspec(dllexport) int AmdPowerXpressRequestHighPerformance = 1;
 }
 #endif
@@ -405,10 +405,11 @@ static void upper_case_property(const char *name)
 }
 
-// Propose NVIDIA Optimus to use high-end GPU
+// Propose NVIDIA Optimus / AMD Xpress to use high-end GPU
 #if defined(SG_WINDOWS)
 extern "C" {